Skip to content

fmodf

产品支持情况

  • Ascend 950PR/Ascend 950DT:支持
  • Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
  • Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
  • Atlas 200I/500 A2 推理产品:不支持
  • Atlas 推理系列产品AI Core:不支持
  • Atlas 推理系列产品Vector Core:不支持
  • Atlas 训练系列产品:不支持

功能说明

获取输入数据x除以y的余数。求余数时,商取x除以y浮点数结果的整数部分。

函数原型

C++
inline float fmodf(float x, float y)

参数说明

表1 参数说明

参数名输入/输出描述
x输入源操作数。
y输入源操作数。

返回值说明

输入数据x除以y的余数。

  • x为0时,y不为0时,返回值为0。
  • x为有限数,y为inf或-inf时,返回值为x。
  • x为inf或-inf,或y为0时,返回值为nan。
  • x,y任意一个为nan时,返回值为nan。

约束说明

需要包含的头文件

使用该接口需要包含"simt_api/math_functions.h"头文件。

C++
#include "simt_api/math_functions.h"

调用示例

  • SIMT编程场景:

    C++
    __global__ __launch_bounds__(256) void compute_fmodf(float *result, const float *x, const float *y, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = fmodf(x[idx], y[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    C++
    __simt_vf__ __launch_bounds__(256) inline void compute_fmodf_vf(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = fmodf(x[idx], y[idx]);
    }
    
    __global__ __vector__ void run_fmodf(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count)
    {
        asc_vf_call<compute_fmodf_vf>(dim3(256), result, x, y, count);
    }
    

输入输出示例如下:

Text
x:0.25, 0.75, 1.25, 1.75
y:1.25, 2.25, 3.25, 4.25
result: 0.25 0.75 1.25 1.75

免责声明:本站内容由 asc-devkit 仓 master 分支自动编译生成,属于持续开发版本,可能存在缺陷,仅供预览与参考。如需稳定及商用资料,请查阅官方 昇腾社区